@@ -2,85 +2,114 @@ from .__version__ import __description__, __title__, __version__
 from ._api import delete, get, head, options, patch, post, put, request, stream
 from ._auth import Auth, BasicAuth, DigestAuth
 from ._client import AsyncClient, Client
-from ._config import PoolLimits, Proxy, Timeout
+from ._config import Limits, PoolLimits, Proxy, Timeout, create_ssl_context
 from ._exceptions import (
+    CloseError,
+    ConnectError,
     ConnectTimeout,
     CookieConflict,
     DecodingError,
     HTTPError,
+    HTTPStatusError,
     InvalidURL,
+    LocalProtocolError,
     NetworkError,
     NotRedirectResponse,
     PoolTimeout,
     ProtocolError,
     ProxyError,
+    ReadError,
     ReadTimeout,
+    RemoteProtocolError,
     RequestBodyUnavailable,
+    RequestError,
     RequestNotRead,
     ResponseClosed,
     ResponseNotRead,
     StreamConsumed,
+    StreamError,
+    TimeoutException,
     TooManyRedirects,
+    TransportError,
+    UnsupportedProtocol,
+    WriteError,
     WriteTimeout,
 )
 from ._models import URL, Cookies, Headers, QueryParams, Request, Response
 from ._status_codes import StatusCode, codes
-from ._transports.asgi import ASGIDispatch, ASGITransport
-from ._transports.urllib3 import URLLib3Transport
-from ._transports.wsgi import WSGIDispatch, WSGITransport
+from ._transports.asgi import ASGITransport
+from ._transports.urllib3 import URLLib3ProxyTransport, URLLib3Transport
+from ._transports.wsgi import WSGITransport
 
 __all__ = [
     "__description__",
     "__title__",
     "__version__",
-    "delete",
-    "get",
-    "head",
-    "options",
-    "patch",
-    "post",
-    "patch",
-    "put",
-    "request",
-    "stream",
-    "codes",
-    "ASGIDispatch",
     "ASGITransport",
     "AsyncClient",
     "Auth",
     "BasicAuth",
     "Client",
-    "DigestAuth",
-    "PoolLimits",
-    "Proxy",
-    "Timeout",
+    "CloseError",
+    "codes",
+    "ConnectError",
     "ConnectTimeout",
     "CookieConflict",
+    "Cookies",
+    "create_ssl_context",
     "DecodingError",
+    "delete",
+    "DigestAuth",
+    "get",
+    "head",
+    "Headers",
     "HTTPError",
+    "HTTPStatusError",
     "InvalidURL",
+    "Limits",
+    "LocalProtocolError",
     "NetworkError",
     "NotRedirectResponse",
+    "options",
+    "patch",
+    "PoolLimits",
     "PoolTimeout",
+    "post",
     "ProtocolError",
+    "Proxy",
+    "ProxyError",
+    "put",
+    "QueryParams",
+    "ReadError",
     "ReadTimeout",
+    "RemoteProtocolError",
+    "request",
+    "Request",
     "RequestBodyUnavailable",
+    "RequestError",
+    "RequestNotRead",
+    "Response",
     "ResponseClosed",
     "ResponseNotRead",
-    "RequestNotRead",
-    "StreamConsumed",
-    "ProxyError",
-    "TooManyRedirects",
-    "WriteTimeout",
-    "URL",
-    "URLLib3Transport",
     "StatusCode",
-    "Cookies",
-    "Headers",
-    "QueryParams",
-    "Request",
-    "Response",
-    "DigestAuth",
-    "WSGIDispatch",
+    "stream",
+    "StreamConsumed",
+    "StreamError",
+    "Timeout",
+    "TimeoutException",
+    "TooManyRedirects",
+    "TransportError",
+    "UnsupportedProtocol",
+    "URL",
+    "URLLib3ProxyTransport",
+    "URLLib3Transport",
+    "WriteError",
+    "WriteTimeout",
     "WSGITransport",
 ]
+
+
+__locals = locals()
+for __name in __all__:
+    if not __name.startswith("__"):
+        setattr(__locals[__name], "__module__", "httpx")  # noqa
